from .temp_mail import *
from .temp_phone import ReceiveSms
from .fake_data import Person
from .fake_data.personcounties import PersonCounties
from .fake_data.utilities import get_password
from .proxies import Proxies, ProxyType
from .countries import Counties
from .captcha_solver import CaptchaSolver


__author__ = 'Dionis1902'
__email__ = 'den70007.ua@gmail.com'
__version__ = '1.0.5'



import re
import requests
from ..mail import letter
from datetime import datetime
from account_generator_helper.utilities import unescape


class Letter(letter.Letter):
    def __init__(self, to, content, proxies):
        letter_id, _from, subject = re.findall(r'.*href="(https://www.gmailnator.com/inbox/.*)">.*<table.*<td.*>(.* <.*>)</td>.*<td.*>(.*)</td>.*<td.*>.*</td>.*', content.replace('\n', ''))[0]
        super().__init__(to, *re.findall(r'(.*) <(.*)>', _from)[0], subject, datetime.fromtimestamp(0), proxies)
        self._letter_id = letter_id

    @property
    def letter(self):
        if self._letter:
            return self._letter
        r = requests.get(self._letter_id, proxies=self._proxies)
        if r.status_code == 200:
            self._letter = unescape(r.text.split('iframe srcdoc="')[1].split('" id="message-body"')[0])
            return self._letter



import re
import requests
from ..mail import letter
from datetime import datetime


class Letter(letter.Letter):
    def __init__(self, url, headers, timestamp, proxies):
        super().__init__(headers['to'], *re.findall(r'(.*) <(.*)>', headers['from'])[0], headers['subject'], datetime.fromtimestamp(timestamp), proxies)
        self._letter_id = '-'.join(re.findall(r'https://(.*)\.api\.mailgun\.net/v3/domains/inboxkitten\.com/messages/(.*)', url)[0])

    @property
    def letter(self):
        if self._letter:
            return self._letter
        r = requests.get(f'https://inboxkitten.com/api/v1/mail/getHtml?mailKey={self._letter_id}', proxies=self._proxies)
        if r.status_code == 200:
            self._letter = re.sub(r'<script[^>]*>([\s\S]*?)</script>', '', r.text)
            return self._letter



import requests
import re


class CaptchaSolver:
    def __init__(self, proxy=None):
        self._s = requests.Session()
        if proxy:
            self._s.proxies.update({'http': proxy, 'https': proxy})
        self.__event_validation = None
        self.__view_state = None
        self.__save_data(self._s.get('https://cloudmersive.com/ocr-api').text)

    def __save_data(self, text):
        self.__event_validation = re.findall(r'__EVENTVALIDATION".*value="(.*)"', text)[0]
        self.__view_state = re.findall(r'__VIEWSTATE".*value="(.*)"', text)[0]

    @staticmethod
    def __get_captcha_result(text):
        result = re.findall(f'TextResult":.*"(.*)"', text)
        if result:
            return result[0].replace('\\n', '')
        return ''

    def solve(self, image: open) -> str:
        """
        Method for solving regular text captcha.

        :param image: open(file, 'rb')
        """
        data = {
            '__EVENTVALIDATION': self.__event_validation,
            '__VIEWSTATE': self.__view_state,
            'ctl00$MainContent$LanguageSelector': 'eng',
            'ctl00$MainContent$btnUpload2': 'Photos of Docs to Text'
        }

        r = self._s.post('https://cloudmersive.com/ocr-api', data=data, files={'ctl00$MainContent$FileUploadBox': image})
        if not r.ok:
            return ''
        self.__save_data(r.text)
        return self.__get_captcha_result(r.text)



import re
import requests
from .constants import ProxyType
from account_generator_helper.proxies.proxy import Proxy
from ..countries import Counties
from threading import Thread, Lock
from bs4 import BeautifulSoup


class Proxies:
    __lock = Lock()

    def __init__(self):
        self.__proxies: list[Proxy] = []

    def _proxy_list(self, _):
        for proxy_type in ProxyType:
            r = requests.get(f'https://www.proxy-list.download/api/v1/get?type={proxy_type.value}')
            if not r.ok:
                continue
            for row in r.text.split():
                with self.__lock:
                    self.__proxies.append(Proxy(proxy_type, *row.split(':'), None))

    def _ssl_proxies(self, _):
        for proxy_type, url in zip([ProxyType.HTTPS, ProxyType.SOCKS4], ['https://www.sslproxies.org/', 'https://www.socks-proxy.net/']):
            resp = requests.get(url)
            for row in self._re_proxy(resp.text):
                address, port, country = row
                try:
                    country = Counties(country.upper())
                except ValueError:
                    country = None
                with self.__lock:
                    self.__proxies.append(Proxy(proxy_type, address, port, country))

    def _hide_me(self, max_page):
        i = 0
        while True:
            r = requests.get(f'https://hidemy.name/ua/proxy-list/?start={i * 64}#list', headers={'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/100.0.4896.75 Safari/537.36'})
            if not r.ok:
                continue
            page = BeautifulSoup(r.text, 'html.parser')
            table = page.find('tbody')
            if not table:
                continue
            for row in table.find_all('tr'):
                address, port, country, _, proxy_type, _, _ = row.find_all('td')
                try:
                    country = getattr(Counties, '_'.join(country.find('span', {'class': 'country'}).text.split(', ')[::-1]).replace(' ', '_').upper())
                except AttributeError:
                    country = None
                with self.__lock:
                    self.__proxies.append(Proxy(getattr(ProxyType, proxy_type.text.split(',')[0].upper()),
                                                address.text, port.text, country))
            if page.find('div', {'class': 'pagination'}).find_all('a')[-1].text.isdigit():
                break
            if max_page and max_page == i:
                break
            i += 1

    @staticmethod
    def _re_proxy(string):
        for row in re.findall(r'<td>([0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3})</td><td>([0-9]{2,5})</td><td>(\D{2})</td>', string):
            yield row

    @property
    def proxies(self) -> list[Proxy]:
        return self.__proxies

    def __worker(self, proxies, good_proxies):
        while proxies:
            __proxy = None
            with self.__lock:
                __proxy = proxies.pop()
            if __proxy.is_valid():
                with self.__lock:
                    good_proxies.append(__proxy)

    def parse_proxies(self, max_page=0):
        """
        Method for parsing all proxies from all services.

        :param max_page: Maximum number of pages from which you need to parse the proxy, 0 if you need to parse all.
        """
        parsers = [self._proxy_list, self._ssl_proxies, self._hide_me]
        threads = [Thread(target=parser, args=(max_page, ), daemon=True) for parser in parsers]
        [thread.start() for thread in threads]
        [thread.join() for thread in threads]

    def test_proxies(self, workers_count=100):
        """
        Method for testing all proxies and saving only working proxies.

        :param workers_count: Threads count.
        """
        testing_proxies, good_proxies = self.__proxies.copy(), []
        threads = [Thread(target=self.__worker, args=(testing_proxies, good_proxies), daemon=True) for _ in range(workers_count)]
        [thread.start() for thread in threads]
        [thread.join() for thread in threads]
        self.__proxies = good_proxies

    def pop(self, index=-1) -> Proxy:
        """
        Remove and return item at index (default last).

        :param index: Index by which to remove and return proxy.
        :return: proxy object.
        """
        with self.__lock:
            return self.__proxies.pop(index)

    def __len__(self):
        return len(self.__proxies)

    def __iter__(self):
        return iter(self.__proxies)

    def __repr__(self):
        return '<Proxies proxies_count={proxies_count}>'.format(proxies_count=len(self.__proxies))



import requests
from ..mail import letter
from datetime import datetime


class Letter(letter.Letter):
    def __init__(self, to, mail, proxies):
        super().__init__(to, mail['from_name'], mail['from_mail'], mail['subject'], datetime.strptime(mail['time'], '%Y-%m-%d %H:%M:%S'), proxies)
        self._letter_id = mail['mail_id']

    @property
    def letter(self):
        if self._letter:
            return self._letter
        r = requests.get(f'https://tempmail.plus/api/mails/{self._letter_id}?email={self._email}', proxies=self._proxies)
        if r.status_code == 200:
            self._letter = r.json()['text']
            return self._letter



import random
import requests
from .country import Country
from account_generator_helper.countries import Counties

headers = {
  'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/100.0.4896.75 Safari/537.36'
}


class Receive:
    def __init__(self, proxy):
        self._s = requests.Session()
        if proxy:
            self._s.proxies.update({'http': proxy, 'https': proxy})
        self._s.headers.update(headers)
        self._countries = []

    def get_counties(self) -> list[Country]:
        """
        :return: List of counties.
        """
        pass

    def get_country(self, country: Counties) -> Country:
        """
        Method returns object of the country, from this object you can get the phone number of this country.

        :param country: Country.
        :return: Country object.
        """
        return dict(enumerate(filter(lambda x: x.country == country, self.get_counties()))).get(0, None)

    def get_random_country(self) -> Country:
        """
        :return: Random Country object.
        """
        return random.choice(self.get_counties())

    def __repr__(self):
        return '<Receive country_count={}>'.format(len(self._countries))



import requests
from .exceptions import ProblemWithGetPersonData
from .personcounties import PersonCounties
from ..utilities import camel_to_snake

headers = {
  'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
}


class Person:
    def __init__(self):
        self._name = None
        self._phone = None
        self._postcode = None
        self._street_address = None
        self._city = None
        self._country = None

        self.update_data()

    @property
    def name(self):
        return self._name

    @property
    def phone(self):
        return self._phone

    @property
    def postcode(self):
        return self._postcode

    @property
    def street_address(self):
        return self._street_address

    @property
    def country(self):
        return self._country

    def update_data(self, country: PersonCounties = PersonCounties.USA):
        """
        Generate new person data.

        :param country: From which country the street.
        """
        r = requests.post('https://www.textreverse.com/frontend/fakeAddressGenerator', data=f'lang={country.value}', headers=headers)
        if r.status_code != 200:
            raise ProblemWithGetPersonData()

        [setattr(self, '_' + camel_to_snake(key), r.json()[0][key]) for key in r.json()[0] if
         self.__getattr('_' + camel_to_snake(key))]

    def __getattr(self, key):
        try:
            getattr(self, key)
            return True
        except AttributeError:
            return False

    def __repr__(self):
        return '<Person {}>'.format(' '.join(['{}={}'.format(key[1:], value) for key, value in zip(vars(self).keys(), vars(self).values())]))





from ..message import Message


class Phone:
    def __init__(self, s, country, url, number, code):
        self._s = s
        self._country = country
        self._url = url
        self._number = number
        self._code = code

    @property
    def country(self):
        """
        :return: Country of phone number.
        """
        return self._country

    @property
    def number(self):
        """
        :return: Phone number.
        """
        return self._number

    def get_last_messages(self) -> list[Message]:
        """
        :return: List of Message objects.
        """
        pass

    def __repr__(self):
        return '<Phone code={} number=+{} country={}>'.format(self._code, self._number, self._country.name)



import random
import string


def get_password(length: int = 16, upper_case=True, numbers=True, special_symbols=True) -> str:
    """
    Function for generate passwords.

    :param length: Length of password.
    :param upper_case: Use upper case.
    :param numbers: Use numbers.
    :param special_symbols: Use special symbols.
    :return: Password.
    """
    data = {'upper_case': string.ascii_uppercase, 'numbers': string.digits, 'special_symbols': string.punctuation}
    _data = locals()
    letters = string.ascii_lowercase + ''.join([data[key] for key in list(_data)[1:4] if _data[key]])
    return ''.join([random.choice(letters) for _ in range(length)])


import re
from ..receive import Receive
from bs4 import BeautifulSoup
from ..exceptions import ProblemWithFetchNumbers
from .country import Country


class ReceiveSms(Receive):
    def __init__(self, proxy=None):
        super().__init__(proxy)

    def get_counties(self):
        if self._countries:
            return self._countries

        def __parse(page_number):
            r = self._s.get(f'https://receive-sms-free.cc/regions/{page_number}.html')
            if r.status_code != 200:
                raise ProblemWithFetchNumbers()
            page = BeautifulSoup(r.text, 'html.parser')
            try:
                _is_need_break = not page.find('ul', {'class': 'pagination'}).find_all('li')[-1].find('a').get('href', False)
            except AttributeError:
                _is_need_break = True

            return [(re.findall(r'.*/(.*).png', e.find('img')['src'])[0].upper(), e.find('a')['href']) for e in page.find_all('li', {'class': 'wow'})], \
                _is_need_break

        i = 0
        while True:
            i += 1
            data, is_need_break = __parse(i)
            self._countries += [Country(self._s, *_country) for _country in data]
            if is_need_break:
                break
        return self._countries



from ..receive import phone
from ..exceptions import ProblemWithFetchNumbers
from ..message import Message
from bs4 import BeautifulSoup


class Phone(phone.Phone):
    def __init__(self, s, country, url, number, code):
        super().__init__(s, country, url, number, code)

    def get_last_messages(self):
        data = []
        r = self._s.get(self._url)
        if r.status_code != 200:
            raise ProblemWithFetchNumbers()

        page = BeautifulSoup(r.text, 'html.parser')
        table = page.find('div', {'class': 'casetext'})
        for e in table.find_all('div', {'class': 'row border-bottom table-hover'}):
            try:
                data.append(Message(e.find('div', {'class': 'col-xs-12 col-md-2'}).find('div').text,
                                    e.find('div', {'class': 'col-xs-12 col-md-8'}).text,
                                    e.find('div', {'class': 'col-xs-0 col-md-2 mobile_hide'}).text))
            except AttributeError:
                pass
        return data



import random
from .phone import Phone
from account_generator_helper.countries import Counties


class Country:
    def __init__(self, s, country, url):
        self._s = s
        self._country = Counties(country)
        self._url = url
        self._phones = []

    @property
    def country(self):
        """
        :return: Country.
        """
        return self._country

    def get_numbers(self) -> list[Phone]:
        """
        :return: List of phone numbers.
        """
        pass

    def get_number(self) -> Phone:
        """
        :return: Random number.
        """
        return random.choice(self.get_numbers())

    def __repr__(self):
        return '<Country country={}>'.format(self._country.name)



from setuptools import setup, find_packages
from pathlib import Path

this_directory = Path(__file__).parent

long_description = (this_directory / 'README.md').read_text()
required = (this_directory / 'requirements.txt').read_text().splitlines()

setup(
    name='account_generator_helper',
    version='1.0.5',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Topic :: Communications :: Email',
        'Topic :: Utilities',
        'Topic :: Internet :: Proxy Servers',
    ],
    project_urls={
        'Source': 'https://github.com/Dionis1902/AccountGeneratorHelper/tree/main/account_generator_helper',
        'Examples': 'https://github.com/Dionis1902/AccountGeneratorHelper/tree/main/examples',
        'Tracker': 'https://github.com/Dionis1902/AccountGeneratorHelper/issues',
    },
    url='https://github.com/DioniS1902/AccountGeneratorHelper',
    license='MIT',
    author='Dionis1902',
    author_email='den70007.ua@gmail.com',
    description='This library is helpful when creating accounts, it has everything you need for this',
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3',
    keywords='python email captcha proxy pypi sms gmail temp-mail captcha-solving captcha-solver fake-data account-generator captcha-recognition fake-data-generator free-proxy recive-sms gmailnator gmailnator-api poxies',
    install_requires=required
)



import requests
from .letter import Letter
from ..exceptions import NotSetEmail
from ..mail import Mail


class InboxKitten(Mail):
    """
    Class for work with https://inboxkitten.com/
    """
    def __init__(self, proxy=None):
        super().__init__(proxy)

    def set_email(self, email):
        """
        Use custom email address.

        :param email: Email address.
        :return: Email address.
        :rtype: str
        """
        return super()._set_email(email) + '@inboxkitten.com'

    def get_inbox(self):
        if not self._email:
            raise NotSetEmail()

        r = requests.get(f'https://inboxkitten.com/api/v1/mail/list?recipient={self._email}', proxies=self._proxies)
        if r.status_code == 200:
            return [Letter(__letter['storage']['url'], __letter['message']['headers'], __letter['timestamp'],
                           self._proxies) for __letter in r.json()]
        return []



from json import JSONDecodeError
import requests
from ..countries import Counties


class Proxy:
    def __init__(self, proxy_type, address, port, country):
        self._proxy_type = proxy_type
        self._address = address
        self._port = int(port)
        self._country = country

    @property
    def proxy_type(self):
        return self._proxy_type

    @property
    def address(self):
        return self._address

    @property
    def port(self):
        return self._port

    @property
    def country(self):
        return self._country

    def get(self, str_format='{proxy_type}://{address}:{port}') -> str:
        """
        Return formatted proxy string.
        {proxy_type} - Proxy type
        {address} - Proxy address
        {port} - Port address

        :param str_format: Example {proxy_type}://{address}:{port}
        :return:
        """
        return str_format.format(proxy_type=self.proxy_type.value, address=self._address, port=self._port)

    def is_valid(self, timeout=10) -> bool:
        """
        Testing proxy.

        :param timeout: Max timeout, default 10 seconds
        :return: bool
        """
        try:
            r = requests.get("http://ip-api.com/json?fields=countryCode", proxies={'http': self.get(), 'https': self.get()}, timeout=timeout)
            try:
                self._country = Counties(r.json()['countryCode'])
            except JSONDecodeError:
                return False
            except ValueError:
                self._country = None
        except IOError:
            return False
        return True

    def __repr__(self):
        return '<Proxy proxy_type={proxy_type} address={address} port={port} country={country}>'.format(
            proxy_type=self.proxy_type.name, address=self._address, port=self._port,
            country=self._country)
